# -*- coding: utf-8 -*-
from setuphelpers import *

# Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_name_string = "googlechromestandaloneenterprise_%s.msi"
silent_args_dict = {"NOGOOGLEUPDATING": 1, "NOGOOGLEUPDATEPING": 1}
app_schtasks_list = ["GoogleUpdateTaskMachineCore", "GoogleUpdateTaskMachineUA"]
app_services_list = ["GoogleChromeElevationService", "gupdate", "gupdatem"]


def install():
    # Declaring local variables
    package_version = control.version.split("-", 1)[0]
    bin_name = bin_name_string % package_version
    skip = False
    if isdir(makepath(programfiles32, "Google", "Chrome", "Application")):
        chrome_app_path = makepath(programfiles32, "Google", "Chrome", "Application")
    else:
        chrome_app_path = makepath(programfiles, "Google", "Chrome", "Application")
    chrome_bin_path = makepath(chrome_app_path, "chrome.exe")
    uninstallkey_from_file = get_msi_properties(bin_name)["ProductCode"]

    def get_version_chrome(key):
        return get_file_properties(chrome_bin_path)["ProductVersion"]

    # Installing the package
    if isfile(chrome_bin_path):
        if Version(get_version_chrome(None)) >= Version(package_version):
            if uninstall_key_exists(uninstallkey_from_file):
                uninstallkey.append(uninstallkey_from_file)
            skip = True

    if (not skip) or force:
        print("Installing: %s" % bin_name)
        install_msi_if_needed(
            bin_name,
            properties=silent_args_dict,
            min_version=package_version,
            get_version=get_version_chrome,
            killbefore=control.impacted_process.split(","),
        )

    # Disabling application scheduled tasks
    for task in app_schtasks_list:
        if task_exists(task):
            try:
                disable_task(task)
            except:
                print("Unable to disable the task: %s" % task)

    # Changing default start mode of the application services
    for service_name in app_services_list:
        if service_installed(service_name):
            if get_service_start_mode(service_name) != "Manual":
                try:
                    set_service_start_mode(service_name, "Manual")
                    if service_is_running(service_name):
                        try:
                            service_stop(service_name)
                        except:
                            print("Unable to stop the service: %s" % service_name)
                except:
                    print("Unable to set start mode of the service: %s" % service_name)

    # Disabling Google Chrome Auto-Update and Telemetry
    registry_setstring(HKEY_LOCAL_MACHINE, r"SOFTWARE\Policies\Google\Update", "UpdateDefault", 0, type=REG_DWORD)
    registry_setstring(HKEY_LOCAL_MACHINE, r"SOFTWARE\Policies\Google\Update", "DisableAutoUpdateChecksCheckboxValue", 1, type=REG_DWORD)
    registry_setstring(HKEY_LOCAL_MACHINE, r"SOFTWARE\Policies\Google\Update", "AutoUpdateCheckPeriodMinutes", 0, type=REG_DWORD)
    registry_setstring(HKEY_LOCAL_MACHINE, r"SOFTWARE\Policies\Explorer\DisallowRun", "chrome_telemetry", "Software_Reporter_Tool.exe", type=REG_SZ)

    # Adding master preferences file
    filecopyto("master_preferences", chrome_app_path)


def uninstall():
    # Uninstalling the package
    if uninstall_key_exists("Google Chrome"):
        if not "msiexec" in " ".join(list(uninstall_cmd("Google Chrome"))).lower():
            versionsoft = get_file_properties(chrome_bin_path)["ProductVersion"]
            run(
                '"%s" --uninstall --system-level --force-uninstall --qn'
                % makepath(install_location("Google Chrome"), versionsoft, "Installer", "setup.exe"),
                accept_returncodes=[19],
            )


def session_setup():
    # Declaring local variables
    swreporter_path = makepath(user_local_appdata, "Google", "Chrome", "User Data", "SwReporter")

    print("Disabling: Telemetry")
    if isdir(swreporter_path):
        remove_tree(swreporter_path)